@@ -14,6 +14,7 @@ class DiscountStrategy(Enum):
 
 
 class CompanySettings(ObjectMS):
+    _type_name = 'companysettings'
 
     @classmethod
     def get_company_settings(cls):
@@ -29,6 +30,13 @@ class CompanySettings(ObjectMS):
         error_handler(response)
         return PriceType(response.json())
 
+    @classmethod
+    def gen_custom_entities(cls):
+        response = MSLowApi.auch_get("context/companysettings/metadata")
+        error_handler(response)
+        for entity_json in response.json().get('customEntities', []):
+            yield CustomEntity(entity_json)
+
     @check_init
     def get_currency(self) -> Currency:
         """Cтандартная валюта"""
@@ -52,11 +60,6 @@ class CompanySettings(ObjectMS):
         иначе нумерация документов будет начинаться заново каждый календарный год."""
         return bool(self._json.get('globalOperationNumbering'))
 
-    @check_init
-    def gen_custom_entities(self):
-        response = MSLowApi.auch_get("context/companysettings/metadata")
-        error_handler(response)
-        for entity_json in response.json().get('customEntities', []):
-            yield CustomEntity(entity_json)
+
 
 
